<?php

namespace Pure\Career\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Pure\Career\Http\Requests\CareerCategoryRequest;
use Pure\Career\Interfaces\CareerCategoryRepositoryInterface;
use Pure\Career\Models\CareerCategory;

/**
 * Resource controller class for career_category.
 */
class CareerCategoryResourceController extends BaseController
{

    /**
     * Initialize career_category resource controller.
     *
     * @param type CareerCategoryRepositoryInterface $career_category
     *
     * @return null
     */
    public function __construct(CareerCategoryRepositoryInterface $career_category)
    {
        parent::__construct();
        $this->repository = $career_category;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Pure\Career\Repositories\Criteria\CareerCategoryResourceCriteria::class);
    }

    /**
     * Display a list of career_category.
     *
     * @return Response
     */
    public function index(CareerCategoryRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Pure\Career\Repositories\Presenter\CareerCategoryPresenter::class)
                ->$function();
        }

        $career_categories = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('career::career_category.names'))
            ->view('career::career_category.index', true)
            ->data(compact('career_categories', 'view'))
            ->output();
    }

    /**
     * Display career_category.
     *
     * @param Request $request
     * @param Model   $career_category
     *
     * @return Response
     */
    public function show(CareerCategoryRequest $request, CareerCategory $career_category)
    {

        if ($career_category->exists) {
            $view = 'career::career_category.show';
        } else {
            $view = 'career::career_category.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('career::career_category.name'))
            ->data(compact('career_category'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new career_category.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(CareerCategoryRequest $request)
    {

        $career_category = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('career::career_category.name')) 
            ->view('career::career_category.create', true) 
            ->data(compact('career_category'))
            ->output();
    }

    /**
     * Create new career_category.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CareerCategoryRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $career_category                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('career::career_category.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('career/career_category/' . $career_category->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/career/career_category'))
                ->redirect();
        }

    }

    /**
     * Show career_category for editing.
     *
     * @param Request $request
     * @param Model   $career_category
     *
     * @return Response
     */
    public function edit(CareerCategoryRequest $request, CareerCategory $career_category)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('career::career_category.name'))
            ->view('career::career_category.edit', true)
            ->data(compact('career_category'))
            ->output();
    }

    /**
     * Update the career_category.
     *
     * @param Request $request
     * @param Model   $career_category
     *
     * @return Response
     */
    public function update(CareerCategoryRequest $request, CareerCategory $career_category)
    {
        try {
            $attributes = $request->all();

            $career_category->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('career::career_category.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('career/career_category/' . $career_category->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('career/career_category/' . $career_category->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the career_category.
     *
     * @param Model   $career_category
     *
     * @return Response
     */
    public function destroy(CareerCategoryRequest $request, CareerCategory $career_category)
    {
        try {

            $career_category->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('career::career_category.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('career/career_category/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('career/career_category/' . $career_category->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple career_category.
     *
     * @param Model   $career_category
     *
     * @return Response
     */
    public function delete(CareerCategoryRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('career::career_category.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('career/career_category'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/career/career_category'))
                ->redirect();
        }

    }

    /**
     * Restore deleted career_categories.
     *
     * @param Model   $career_category
     *
     * @return Response
     */
    public function restore(CareerCategoryRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('career::career_category.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/career/career_category'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/career/career_category/'))
                ->redirect();
        }

    }

}
