<?php

namespace Pure\Career\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Pure\Career\Http\Requests\CareerMetaRequest;
use Pure\Career\Interfaces\CareerMetaRepositoryInterface;
use Pure\Career\Models\CareerMeta;

/**
 * Resource controller class for career_meta.
 */
class CareerMetaResourceController extends BaseController
{

    /**
     * Initialize career_meta resource controller.
     *
     * @param type CareerMetaRepositoryInterface $career_meta
     *
     * @return null
     */
    public function __construct(CareerMetaRepositoryInterface $career_meta)
    {
        parent::__construct();
        $this->repository = $career_meta;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Pure\Career\Repositories\Criteria\CareerMetaResourceCriteria::class);
    }

    /**
     * Display a list of career_meta.
     *
     * @return Response
     */
    public function index(CareerMetaRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Pure\Career\Repositories\Presenter\CareerMetaPresenter::class)
                ->$function();
        }

        $career_metas = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('career::career_meta.names'))
            ->view('career::career_meta.index', true)
            ->data(compact('career_metas', 'view'))
            ->output();
    }

    /**
     * Display career_meta.
     *
     * @param Request $request
     * @param Model   $career_meta
     *
     * @return Response
     */
    public function show(CareerMetaRequest $request, CareerMeta $career_meta)
    {

        if ($career_meta->exists) {
            $view = 'career::career_meta.show';
        } else {
            $view = 'career::career_meta.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('career::career_meta.name'))
            ->data(compact('career_meta'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new career_meta.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(CareerMetaRequest $request)
    {

        $career_meta = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('career::career_meta.name')) 
            ->view('career::career_meta.create', true) 
            ->data(compact('career_meta'))
            ->output();
    }

    /**
     * Create new career_meta.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CareerMetaRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $career_meta                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('career::career_meta.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('career/career_meta/' . $career_meta->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/career/career_meta'))
                ->redirect();
        }

    }

    /**
     * Show career_meta for editing.
     *
     * @param Request $request
     * @param Model   $career_meta
     *
     * @return Response
     */
    public function edit(CareerMetaRequest $request, CareerMeta $career_meta)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('career::career_meta.name'))
            ->view('career::career_meta.edit', true)
            ->data(compact('career_meta'))
            ->output();
    }

    /**
     * Update the career_meta.
     *
     * @param Request $request
     * @param Model   $career_meta
     *
     * @return Response
     */
    public function update(CareerMetaRequest $request, CareerMeta $career_meta)
    {
        try {
            $attributes = $request->all();

            $career_meta->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('career::career_meta.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('career/career_meta/' . $career_meta->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('career/career_meta/' . $career_meta->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the career_meta.
     *
     * @param Model   $career_meta
     *
     * @return Response
     */
    public function destroy(CareerMetaRequest $request, CareerMeta $career_meta)
    {
        try {

            $career_meta->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('career::career_meta.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('career/career_meta/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('career/career_meta/' . $career_meta->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple career_meta.
     *
     * @param Model   $career_meta
     *
     * @return Response
     */
    public function delete(CareerMetaRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('career::career_meta.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('career/career_meta'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/career/career_meta'))
                ->redirect();
        }

    }

    /**
     * Restore deleted career_metas.
     *
     * @param Model   $career_meta
     *
     * @return Response
     */
    public function restore(CareerMetaRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('career::career_meta.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/career/career_meta'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/career/career_meta/'))
                ->redirect();
        }

    }

}
